Demos
=====

The documents in this section show demos of the standard evaluator.

.. toctree::
   :maxdepth: 1

   Problem_explanation
   defining_options
   group_creation_NASA
   group_manipulation
   group_reading
   